from re import X
from pyfiglet import Figlet
class Artwork():
    
        def art():
          f = Figlet(font='larry3d')
          print("\n https://github.com/rileydakota/cfn-sweeper" )
          print (f.renderText('CFN SWEEPER \n'))  
          print(("          The umanaged resource detector tool!").center(20))
          print(("-----------------------------------------------------------").center(24, " "))
          print(("                    Run Report").center(20))
          print(("-----------------------------------------------------------").center(24, " "))